Struct World
pub struct World {
pub(crate) sim: WorldSim,
pub(crate) civs: Civs,
}Fields
sim: WorldSimcivs: CivsImplementations
impl World
impl World
pub fn empty() -> (World, IndexOwned)
pub fn generate( seed: u32, opts: WorldOpts, threadpool: &ThreadPool, report_stage: &(dyn Fn(WorldGenerateStage) + Send + Sync), ) -> (World, IndexOwned)
pub fn sim(&self) -> &WorldSim
pub fn civs(&self) -> &Civs
pub fn tick(&self, _dt: Duration)
pub fn get_map_data( &self, index: IndexRef<'_>, threadpool: &ThreadPool, ) -> WorldMapMsg
pub fn sample_columns( &self, ) -> impl Sampler<'_, Index = (Vec2<i32>, IndexRef<'_>, Option<&Calendar>), Sample = Option<ColumnSample<'_>>>
pub fn sample_blocks(&self) -> BlockGen<'_>
pub fn find_accessible_pos(
&self,
index: IndexRef<'_>,
spawn_wpos: Vec2<i32>,
ascending: bool,
) -> Vec3<f32>
pub fn find_accessible_pos( &self, index: IndexRef<'_>, spawn_wpos: Vec2<i32>, ascending: bool, ) -> Vec3<f32>
Find a position that’s accessible to a player at the given world position by searching blocks vertically.
If ascending is true, we try to find the highest accessible position
instead of the lowest.
pub fn generate_chunk( &self, index: IndexRef<'_>, chunk_pos: Vec2<i32>, rtsim_resources: Option<EnumMap<TerrainResource, f32>>, should_continue: impl FnMut() -> bool, time: Option<(TimeOfDay, Calendar)>, ) -> Result<(Chonk<Block, TerrainChunkSize, TerrainChunkMeta>, ChunkSupplement), ()>
pub fn get_lod_zone(&self, pos: Vec2<i32>, index: IndexRef<'_>) -> Zone
pub fn get_location_name( &self, index: IndexRef<'_>, wpos2d: Vec2<i32>, ) -> Option<String>